==> solr_search_synonym-1.0.3.tar.gz: solr_search_synonym/src/Controller/SolrSynonymUploaderBatchExport.php <==
<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
namespace Drupal\solr_search_synonym\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 *
 */
class SolrSynonymUploaderBatchExport extends ControllerBase {

  /**
   *
   */
  public function index() {
    $pluginManager = \Drupal::service('plugin.manager.solr_search_synonym.export');
    $conf = \Drupal::configFactory()->getEditable('solr_search_synonym.settings')->get('cron');
    $plugin = 'solr_uploader';
    $options = [
      'langcode' => \Drupal::languageManager()->getCurrentLanguage()->getId(),
      'type' => $conf['type'],
      'filter' => $conf['filter']
    ];
    $pluginManager->setPluginId($plugin);
    $pluginManager->setExportOptions($options);
    $synonyms = $pluginManager->getSynonymsData();
    $redirect_url = '/admin/config/search/solr-search-synonyms';
    if (!empty($synonyms)) {
      $batch = array(
            'title' => t('Import Data...'),
            'operations' => [],
            'init_message' => t('Commencing'),
            'progress_message' => t('Processing Synonyms'),
            'error_message' => t('An error occurred during processing'),
            'finished' => '\Drupal\solr_search_synonym\Controller\SolrSynonymUploaderBatchExport::import_data_finished',
        );
     
      foreach($synonyms as $synonym){
        $instance = $pluginManager->createInstance($plugin, []);
        $lines[] = $instance->generateLine($synonym->word, $synonym->synonyms, $synonym->type);     
      }
      $batch['operations'][] = ['\Drupal\solr_search_synonym\Controller\SolrSynonymUploaderBatchExport::import_data', [$lines]];
      batch_set($batch);
      return batch_process($redirect_url);
    }
    else{
      \Drupal::messenger()->addStatus('No Synonyms found.');
      return new RedirectResponse($redirect_url);
    }
   
  }


  function import_data($lines, &$context)
  {
    $pluginManager = \Drupal::service('plugin.manager.solr_search_synonym.export');
    $plugin = 'solr_uploader';
    $instance = $pluginManager->createInstance($plugin, []);
    // Get search api's server entities.
    $query = \Drupal::entityQuery('search_api_server');
    // Get the search servers.
    $servers = $query->execute();
    // Loop through the search servers.
    foreach ($servers as $server_id) {
      $server_storage = \Drupal::entityTypeManager()->getStorage('search_api_server');
      $server = $server_storage->load($server_id);
      $backend = $server->getBackend();

      // Only export synoyms for Solr servers.
      if (is_a($backend, 'Drupal\search_api_solr\Plugin\search_api\backend\SearchApiSolrBackend')) {

        // Retrieve the Solr Connector which actually communicates
        // with the Solr server.
        $solr_connector = $backend->getSolrConnector();


        // Purge all synonyms from Solr.
        $instance->purgeSolrSynoymns($solr_connector);

        // Loop through each line of synonym mappings
        // and add to Solr.
        foreach ($lines as $line) {
          $path = 'schema/analysis/synonyms/english';
          $output = $solr_connector->coreRestPost($path, $line);
        }

        // Reload Solr Core to activate synoymns.
        $solr_connector->reloadCore();

        // Que the index to re-index content.
        $indexes = $server->getIndexes();
        foreach ($indexes as $key => $index) {
          $index->reindex();
        }
      }
    }
    $context['message'] = 'Export Synonyms to Solr....';
    $context['results'] = count($lines);
    usleep(50000);
  }

  function import_data_finished($success, $results, $operations)
  {
    if ($success) {
      $message = \Drupal::translation()->formatPlural(
            $results,
            'One item processed.', '@count items processed.'
        );

    } else {
        $message = t('Finished with an error.');
    }
    \Drupal::messenger()->addStatus($message);
  }

}

==> solr_search_synonym-1.0.4.tar.gz: solr_search_synonym/src/Controller/SolrSynonymUploaderBatchExport.php <==
<?php

/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
namespace Drupal\solr_search_synonym\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 *
 */
class SolrSynonymUploaderBatchExport extends ControllerBase {

  /**
   *
   */
  public function index() {
    $pluginManager = \Drupal::service('plugin.manager.solr_search_synonym.export');
    $conf = \Drupal::configFactory()->getEditable('solr_search_synonym.settings')->get('cron');
    $plugin = 'solr_uploader';
    $options = [
      'langcode' => \Drupal::languageManager()->getCurrentLanguage()->getId(),
      'type' => $conf['type'],
      'filter' => $conf['filter'],
    ];
    $pluginManager->setPluginId($plugin);
    $pluginManager->setExportOptions($options);
    $synonyms = $pluginManager->getSynonymsData();
    $redirect_url = '/admin/config/search/solr-search-synonyms';
    if (!empty($synonyms)) {
      $batch = [
        'title' => t('Import Data...'),
        'operations' => [],
        'init_message' => t('Commencing'),
        'progress_message' => t('Processing Synonyms'),
        'error_message' => t('An error occurred during processing'),
        'finished' => '\Drupal\solr_search_synonym\Controller\SolrSynonymUploaderBatchExport::import_data_finished',
      ];

      foreach ($synonyms as $synonym) {
        $instance = $pluginManager->createInstance($plugin, []);
        $lines[] = $instance->generateLine($synonym->word, $synonym->synonyms, $synonym->type);
      }
      $batch['operations'][] = ['\Drupal\solr_search_synonym\Controller\SolrSynonymUploaderBatchExport::import_data', [$lines]];
      batch_set($batch);
      return batch_process($redirect_url);
    }
    else {
      \Drupal::messenger()->addStatus('No Synonyms found.');
      return new RedirectResponse($redirect_url);
    }

  }

  /**
   *
   */
  public function import_data($lines, &$context) {
    $pluginManager = \Drupal::service('plugin.manager.solr_search_synonym.export');
    $plugin = 'solr_uploader';
    $instance = $pluginManager->createInstance($plugin, []);
    // Get search api's server entities.
    $query = \Drupal::entityQuery('search_api_server');
    // Get the search servers.
    $servers = $query->execute();
    // Loop through the search servers.
    foreach ($servers as $server_id) {
      $server_storage = \Drupal::entityTypeManager()->getStorage('search_api_server');
      $server = $server_storage->load($server_id);
      $backend = $server->getBackend();

      // Only export synoyms for Solr servers.
      if (is_a($backend, 'Drupal\search_api_solr\Plugin\search_api\backend\SearchApiSolrBackend')) {

        // Retrieve the Solr Connector which actually communicates
        // with the Solr server.
        $solr_connector = $backend->getSolrConnector();

        // Purge all synonyms from Solr.
        $instance->purgeSolrSynoymns($solr_connector);

        // Loop through each line of synonym mappings
        // and add to Solr.
        foreach ($lines as $line) {
          $path = 'schema/analysis/synonyms/english';
          $output = $solr_connector->coreRestPost($path, $line);
        }

        // Reload Solr Core to activate synoymns.
        $solr_connector->reloadCore();

        // Que the index to re-index content.
        $indexes = $server->getIndexes();
        foreach ($indexes as $key => $index) {
          $index->reindex();
        }
      }
    }
    $context['message'] = 'Export Synonyms to Solr....';
    $context['results'] = count($lines);
    usleep(50000);
  }

  /**
   *
   */
  public function import_data_finished($success, $results, $operations) {
    if ($success) {
      $message = \Drupal::translation()->formatPlural(
            $results,
            'One item processed.', '@count items processed.'
        );

    }
    else {
      $message = t('Finished with an error.');
    }
    \Drupal::messenger()->addStatus($message);
  }

}
